@@ -12,10 +12,6 @@ UI::Various - graphical/non-graphical user interface without external programs
 
 =head1 ABSTRACT
 
-B<This module is still WORK IN PROGRESS, but already usable with some
-restrictions.> Currently it provides basic functionality only (no dialogues,
-no frills).
-
 Did you ever need to decide if a graphical or text based user interface is
 best for your Perl application?  A GUI may be easier to use, but will not
 run on run on a server without a window system (like X11 or Wayland) and
@@ -40,6 +36,12 @@ pictures or icons (unless the later are part of the character set used) need
 alternative descriptions for the text based interfaces, which can make a big
 difference in the usability.
 
+Currently the module is still missing some of its planned frills like
+alignment, colour, exact positioning, graphics, pictures or icons.  At least
+the first two of this list will be added in later versions.  The essential
+functionality is ready to be used and will be tested / used by another
+project developed before further enhancements on this one.
+
 =head1 DESCRIPTION
 
 UI::Various is a user interface (UI) choosing the best available UI from a
@@ -124,7 +126,7 @@ use warnings 'once';
 
 use Carp;			# may only be used in import!
 
-our $VERSION = "0.24";
+our $VERSION = "0.25";
 
 BEGIN  {  require UI::Various::core;  }
 
@@ -233,6 +235,11 @@ catch all error messages and print them when the program exits (or you
 switch back to C<0>) in order to avoid cluttering the terminal output,
 e.g. when running under Curses
 
+Note that under Curses you probably even then still won't see the output, as
+the ncurses library apparently clears the terminal after Perl's END
+handlers.  See C<examples/listbox.pl> and C<examples/select-file.pl> for a
+possible mitigation.
+
 =item C<1>
 
 identical to C<2> when using a TUI and identical to C<0> when using a GUI
