@@ -32,7 +32,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 use UI::Various::core;
 use UI::Various::Listbox;
@@ -159,6 +159,26 @@ sub _remove($$)
 
 #########################################################################
 
+=head2 B<_replace> - replace all elements
+
+C<PoorTerm>'s specific implementation of
+L<UI::Various::Listbox::replace|UI::Various::Listbox/replace - replace all
+elements>
+
+=cut
+
+# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
+
+sub _replace($@)
+{
+    my ($self) = shift;
+    $self->_cui->clear_selection();
+    $self->_cui->values($self->{texts});
+    $self->_cui->intellidraw();
+}
+
+#########################################################################
+
 =head2 B<_selected> - get current selection of listbox
 
 C<PoorTerm>'s specific implementation of
